Module: Plushie::App::DefaultCallbacks Private
- Defined in:
- lib/plushie/app.rb
Overview
This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.
Default no-op implementations for optional callbacks.
Instance Method Summary collapse
-
#handle_renderer_exit(model, _reason) ⇒ Object
private
Override to handle renderer process exit.
-
#settings ⇒ Object
private
Override to provide application-level settings to the renderer.
-
#subscribe(_model) ⇒ Object
private
Override to return active subscriptions based on the model.
-
#window_config(_model) ⇒ Object
private
Override to configure default window properties.
Instance Method Details
#handle_renderer_exit(model, _reason) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Override to handle renderer process exit. Default: return model unchanged.
72 |
# File 'lib/plushie/app.rb', line 72 def handle_renderer_exit(model, _reason) = model |
#settings ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Override to provide application-level settings to the renderer. Default: empty (renderer defaults).
64 |
# File 'lib/plushie/app.rb', line 64 def settings = {} |
#subscribe(_model) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Override to return active subscriptions based on the model. Default: no subscriptions.
60 |
# File 'lib/plushie/app.rb', line 60 def subscribe(_model) = [] |
#window_config(_model) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Override to configure default window properties. Default: empty (renderer defaults).
68 |
# File 'lib/plushie/app.rb', line 68 def window_config(_model) = {} |