Class: Plushie::Event::Diagnostic::RequiredWidgetsMissing

Inherits:
Data
  • Object
show all
Defined in:
lib/plushie/event/diagnostic.rb

Overview

The Settings handshake declared one or more native widget type names that the renderer does not know about.

Instance Attribute Summary collapse

Instance Attribute Details

#missingObject (readonly)

Returns the value of attribute missing

Returns:

  • (Object)

    the current value of missing



110
111
112
# File 'lib/plushie/event/diagnostic.rb', line 110

def missing
  @missing
end