Class: Plushie::Event::SessionClosed

Inherits:
Data
  • Object
show all
Defined in:
lib/plushie/event.rb,
sig/plushie/event.rbs

Overview

A multiplexed session was closed by the renderer.

Emitted after a Reset completes and the session thread exits.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initializeSessionClosed

Returns a new instance of SessionClosed.

Parameters:

  • session: (String)
  • reason: (String)


250
# File 'sig/plushie/event.rbs', line 250

def initialize: (session: String, reason: String) -> void

Instance Attribute Details

#reasonObject (readonly)

Returns the value of attribute reason

Returns:

  • (Object)

    the current value of reason



388
389
390
# File 'lib/plushie/event.rb', line 388

def reason
  @reason
end

#reason [String] close reason from the renderer([String]) ⇒ Object (readonly)

A multiplexed session was closed by the renderer.

Emitted after a Reset completes and the session thread exits.



388
# File 'lib/plushie/event.rb', line 388

SessionClosed = Data.define(:session, :reason)

#sessionObject (readonly)

Returns the value of attribute session

Returns:

  • (Object)

    the current value of session



388
389
390
# File 'lib/plushie/event.rb', line 388

def session
  @session
end

#session [String] the session ID that was closed([String]) ⇒ Object (readonly)

A multiplexed session was closed by the renderer.

Emitted after a Reset completes and the session thread exits.



388
# File 'lib/plushie/event.rb', line 388

SessionClosed = Data.define(:session, :reason)

Instance Method Details

#withSessionClosed

Parameters:

  • (Object)

Returns:



251
# File 'sig/plushie/event.rbs', line 251

def with: (**untyped) -> SessionClosed