Class: Plushie::Event::SessionError

Inherits:
Data
  • Object
show all
Defined in:
lib/plushie/event.rb

Overview

A multiplexed session encountered an error.

Emitted by the renderer when a session thread panics, hits a session-scoped cap, or otherwise fails. Only delivered when the renderer is run with --max-sessions > 1.

Examples:

in Event::SessionError[session:, code:, error:]
  logger.error("session #{session} failed (#{code}): #{error}")

Instance Attribute Summary collapse

Instance Attribute Details

#codeObject (readonly)

Returns the value of attribute code

Returns:

  • (Object)

    the current value of code



380
381
382
# File 'lib/plushie/event.rb', line 380

def code
  @code
end

#code [String] stable diagnostic code: `session_panic`,([String]) ⇒ Object (readonly)

max_sessions_reached, session_channel_closed, writer_dead, font_cap_exceeded, renderer_panic, session_reset_in_progress, session_backpressure_overflow



380
# File 'lib/plushie/event.rb', line 380

SessionError = Data.define(:session, :code, :error)

#errorObject (readonly)

Returns the value of attribute error

Returns:

  • (Object)

    the current value of error



380
381
382
# File 'lib/plushie/event.rb', line 380

def error
  @error
end

#error [String] human-readable error description([String]) ⇒ Object (readonly)

A multiplexed session encountered an error.

Emitted by the renderer when a session thread panics, hits a session-scoped cap, or otherwise fails. Only delivered when the renderer is run with --max-sessions > 1.

Examples:

in Event::SessionError[session:, code:, error:]
  logger.error("session #{session} failed (#{code}): #{error}")


380
# File 'lib/plushie/event.rb', line 380

SessionError = Data.define(:session, :code, :error)

#sessionObject (readonly)

Returns the value of attribute session

Returns:

  • (Object)

    the current value of session



380
381
382
# File 'lib/plushie/event.rb', line 380

def session
  @session
end

#session [String] the session ID that errored([String]) ⇒ Object (readonly)

A multiplexed session encountered an error.

Emitted by the renderer when a session thread panics, hits a session-scoped cap, or otherwise fails. Only delivered when the renderer is run with --max-sessions > 1.

Examples:

in Event::SessionError[session:, code:, error:]
  logger.error("session #{session} failed (#{code}): #{error}")


380
# File 'lib/plushie/event.rb', line 380

SessionError = Data.define(:session, :code, :error)