Class: Plushie::Route::State
- Inherits:
-
Data
- Object
- Data
- Plushie::Route::State
- Includes:
- Model::Extensions
- Defined in:
- lib/plushie/route.rb
Overview
Immutable route state.
Instance Attribute Summary collapse
-
#stack ⇒ Object
readonly
Returns the value of attribute stack.
Instance Method Summary collapse
-
#with(**changes) ⇒ Object
included
from Model::Extensions
private
Return a new instance with the given fields replaced.
Instance Attribute Details
#stack ⇒ Object (readonly)
Returns the value of attribute stack
21 22 23 |
# File 'lib/plushie/route.rb', line 21 def stack @stack end |
Instance Method Details
#with(**changes) ⇒ Object Originally defined in module Model::Extensions
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Return a new instance with the given fields replaced. Unspecified fields carry over from the current instance.
model.with(count: model.count + 1)