Class: Plushie::Event::CommandError
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::CommandError
- Defined in:
- lib/plushie/event.rb
Overview
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
Instance Attribute Summary collapse
-
#family ⇒ Object
readonly
Returns the value of attribute family.
-
#family [String, nil] command family name([String, nil]) ⇒ Object
readonly
Renderer error for a command.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#id [String, nil] target widget ID([String, nil]) ⇒ Object
readonly
Renderer error for a command.
-
#message ⇒ Object
readonly
Returns the value of attribute message.
-
#message [String, nil] human-readable error text([String, nil]) ⇒ Object
readonly
Renderer error for a command.
-
#reason ⇒ Object
readonly
Returns the value of attribute reason.
-
#reason [String] machine-readable error reason([String]) ⇒ Object
readonly
Renderer error for a command.
-
#widget_type ⇒ Object
readonly
Returns the value of attribute widget_type.
-
#widget_type [String, nil] widget type name([String, nil]) ⇒ Object
readonly
Renderer error for a command.
Instance Method Summary collapse
-
#initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) ⇒ CommandError
constructor
A new instance of CommandError.
Constructor Details
#initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) ⇒ CommandError
Returns a new instance of CommandError.
311 312 313 |
# File 'lib/plushie/event.rb', line 311 def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end |
Instance Attribute Details
#family ⇒ Object (readonly)
Returns the value of attribute family
310 311 312 |
# File 'lib/plushie/event.rb', line 310 def family @family end |
#family [String, nil] command family name([String, nil]) ⇒ Object (readonly)
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
310 311 312 313 314 |
# File 'lib/plushie/event.rb', line 310 CommandError = Data.define(:reason, :id, :family, :widget_type, :message) do def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end end |
#id ⇒ Object (readonly)
Returns the value of attribute id
310 311 312 |
# File 'lib/plushie/event.rb', line 310 def id @id end |
#id [String, nil] target widget ID([String, nil]) ⇒ Object (readonly)
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
310 311 312 313 314 |
# File 'lib/plushie/event.rb', line 310 CommandError = Data.define(:reason, :id, :family, :widget_type, :message) do def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end end |
#message ⇒ Object (readonly)
Returns the value of attribute message
310 311 312 |
# File 'lib/plushie/event.rb', line 310 def @message end |
#message [String, nil] human-readable error text([String, nil]) ⇒ Object (readonly)
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
310 311 312 313 314 |
# File 'lib/plushie/event.rb', line 310 CommandError = Data.define(:reason, :id, :family, :widget_type, :message) do def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end end |
#reason ⇒ Object (readonly)
Returns the value of attribute reason
310 311 312 |
# File 'lib/plushie/event.rb', line 310 def reason @reason end |
#reason [String] machine-readable error reason([String]) ⇒ Object (readonly)
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
310 311 312 313 314 |
# File 'lib/plushie/event.rb', line 310 CommandError = Data.define(:reason, :id, :family, :widget_type, :message) do def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end end |
#widget_type ⇒ Object (readonly)
Returns the value of attribute widget_type
310 311 312 |
# File 'lib/plushie/event.rb', line 310 def @widget_type end |
#widget_type [String, nil] widget type name([String, nil]) ⇒ Object (readonly)
Renderer error for a command.
Emitted when the renderer cannot deliver or execute a command.
310 311 312 313 314 |
# File 'lib/plushie/event.rb', line 310 CommandError = Data.define(:reason, :id, :family, :widget_type, :message) do def initialize(reason:, id: nil, family: nil, widget_type: nil, message: nil) super end end |