Class: Plushie::Event::Diagnostic::RequiredWidgetsMissing
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::Diagnostic::RequiredWidgetsMissing
- Defined in:
- lib/plushie/event/diagnostic.rb
Overview
The Settings handshake declared one or more native widget type names that the renderer does not know about.
Instance Attribute Summary collapse
-
#missing ⇒ Object
readonly
Returns the value of attribute missing.
Instance Attribute Details
#missing ⇒ Object (readonly)
Returns the value of attribute missing
110 111 112 |
# File 'lib/plushie/event/diagnostic.rb', line 110 def missing @missing end |