Class: Plushie::Event::SessionClosed
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::SessionClosed
- Defined in:
- lib/plushie/event.rb
Overview
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
Instance Attribute Summary collapse
-
#reason ⇒ Object
readonly
Returns the value of attribute reason.
-
#reason [String] close reason from the renderer([String]) ⇒ Object
readonly
A multiplexed session was closed by the renderer.
-
#session ⇒ Object
readonly
Returns the value of attribute session.
-
#session [String] the session ID that was closed([String]) ⇒ Object
readonly
A multiplexed session was closed by the renderer.
Instance Attribute Details
#reason ⇒ Object (readonly)
Returns the value of attribute reason
388 389 390 |
# File 'lib/plushie/event.rb', line 388 def reason @reason end |
#reason [String] close reason from the renderer([String]) ⇒ Object (readonly)
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
388 |
# File 'lib/plushie/event.rb', line 388 SessionClosed = Data.define(:session, :reason) |
#session ⇒ Object (readonly)
Returns the value of attribute session
388 389 390 |
# File 'lib/plushie/event.rb', line 388 def session @session end |
#session [String] the session ID that was closed([String]) ⇒ Object (readonly)
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
388 |
# File 'lib/plushie/event.rb', line 388 SessionClosed = Data.define(:session, :reason) |