Class: Plushie::Event::SessionClosed
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::SessionClosed
- Defined in:
- lib/plushie/event.rb,
sig/plushie/event.rbs
Overview
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
Instance Attribute Summary collapse
-
#reason ⇒ Object
readonly
Returns the value of attribute reason.
-
#reason [String] close reason from the renderer([String]) ⇒ Object
readonly
A multiplexed session was closed by the renderer.
-
#session ⇒ Object
readonly
Returns the value of attribute session.
-
#session [String] the session ID that was closed([String]) ⇒ Object
readonly
A multiplexed session was closed by the renderer.
Instance Method Summary collapse
-
#initialize ⇒ SessionClosed
constructor
A new instance of SessionClosed.
- #with ⇒ SessionClosed
Constructor Details
#initialize ⇒ SessionClosed
Returns a new instance of SessionClosed.
250 |
# File 'sig/plushie/event.rbs', line 250
def initialize: (session: String, reason: String) -> void
|
Instance Attribute Details
#reason ⇒ Object (readonly)
Returns the value of attribute reason
388 389 390 |
# File 'lib/plushie/event.rb', line 388 def reason @reason end |
#reason [String] close reason from the renderer([String]) ⇒ Object (readonly)
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
388 |
# File 'lib/plushie/event.rb', line 388 SessionClosed = Data.define(:session, :reason) |
#session ⇒ Object (readonly)
Returns the value of attribute session
388 389 390 |
# File 'lib/plushie/event.rb', line 388 def session @session end |
#session [String] the session ID that was closed([String]) ⇒ Object (readonly)
A multiplexed session was closed by the renderer.
Emitted after a Reset completes and the session thread exits.
388 |
# File 'lib/plushie/event.rb', line 388 SessionClosed = Data.define(:session, :reason) |
Instance Method Details
#with ⇒ SessionClosed
251 |
# File 'sig/plushie/event.rbs', line 251
def with: (**untyped) -> SessionClosed
|