Class: Plushie::Event::SessionError
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::SessionError
- Defined in:
- lib/plushie/event.rb
Overview
A multiplexed session encountered an error.
Emitted by the renderer when a session thread panics, hits a
session-scoped cap, or otherwise fails. Only delivered when the
renderer is run with --max-sessions > 1.
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
-
#code [String] stable diagnostic code: `session_panic`,([String]) ⇒ Object
readonly
max_sessions_reached,session_channel_closed,writer_dead,font_cap_exceeded,renderer_panic,session_reset_in_progress,session_backpressure_overflow. -
#error ⇒ Object
readonly
Returns the value of attribute error.
-
#error [String] human-readable error description([String]) ⇒ Object
readonly
A multiplexed session encountered an error.
-
#session ⇒ Object
readonly
Returns the value of attribute session.
-
#session [String] the session ID that errored([String]) ⇒ Object
readonly
A multiplexed session encountered an error.
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code
380 381 382 |
# File 'lib/plushie/event.rb', line 380 def code @code end |
#code [String] stable diagnostic code: `session_panic`,([String]) ⇒ Object (readonly)
max_sessions_reached, session_channel_closed, writer_dead,
font_cap_exceeded, renderer_panic, session_reset_in_progress,
session_backpressure_overflow
380 |
# File 'lib/plushie/event.rb', line 380 SessionError = Data.define(:session, :code, :error) |
#error ⇒ Object (readonly)
Returns the value of attribute error
380 381 382 |
# File 'lib/plushie/event.rb', line 380 def error @error end |
#error [String] human-readable error description([String]) ⇒ Object (readonly)
A multiplexed session encountered an error.
Emitted by the renderer when a session thread panics, hits a
session-scoped cap, or otherwise fails. Only delivered when the
renderer is run with --max-sessions > 1.
380 |
# File 'lib/plushie/event.rb', line 380 SessionError = Data.define(:session, :code, :error) |
#session ⇒ Object (readonly)
Returns the value of attribute session
380 381 382 |
# File 'lib/plushie/event.rb', line 380 def session @session end |
#session [String] the session ID that errored([String]) ⇒ Object (readonly)
A multiplexed session encountered an error.
Emitted by the renderer when a session thread panics, hits a
session-scoped cap, or otherwise fails. Only delivered when the
renderer is run with --max-sessions > 1.
380 |
# File 'lib/plushie/event.rb', line 380 SessionError = Data.define(:session, :code, :error) |