Class: Plushie::Event::System
- Inherits:
-
Data
- Object
- Data
- Plushie::Event::System
- Defined in:
- lib/plushie/event.rb
Overview
System events for theme changes, animation frames, and other runtime signals. Triggered by OS-level changes or renderer lifecycle events. Subscribe via Subscription.on_theme_change or on_animation_frame.
Instance Attribute Summary collapse
-
#data ⇒ Object
readonly
Returns the value of attribute data.
-
#data [Object, nil] event payload (theme name for :theme_changed, delta ms for :animation_frame)([Object, nil](theme name) ⇒ Object
readonly
System events for theme changes, animation frames, and other runtime signals.
-
#tag ⇒ Object
readonly
Returns the value of attribute tag.
-
#tag [Symbol, nil] subscription tag (for :animation_frame)([Symbol, nil]() ⇒ Object
readonly
System events for theme changes, animation frames, and other runtime signals.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
-
#type [Symbol] :theme_changed, :animation_frame([Symbol], : animation_frame) ⇒ Object
readonly
System events for theme changes, animation frames, and other runtime signals.
Instance Method Summary collapse
-
#initialize(type:, tag: nil, data: nil) ⇒ System
constructor
A new instance of System.
Constructor Details
#initialize(type:, tag: nil, data: nil) ⇒ System
Returns a new instance of System.
278 279 280 |
# File 'lib/plushie/event.rb', line 278 def initialize(type:, tag: nil, data: nil) super end |
Instance Attribute Details
#data ⇒ Object (readonly)
Returns the value of attribute data
277 278 279 |
# File 'lib/plushie/event.rb', line 277 def data @data end |
#data [Object, nil] event payload (theme name for :theme_changed, delta ms for :animation_frame)([Object, nil](theme name) ⇒ Object (readonly)
System events for theme changes, animation frames, and other runtime signals. Triggered by OS-level changes or renderer lifecycle events. Subscribe via Subscription.on_theme_change or on_animation_frame.
277 278 279 280 281 |
# File 'lib/plushie/event.rb', line 277 System = Data.define(:type, :tag, :data) do def initialize(type:, tag: nil, data: nil) super end end |
#tag ⇒ Object (readonly)
Returns the value of attribute tag
277 278 279 |
# File 'lib/plushie/event.rb', line 277 def tag @tag end |
#tag [Symbol, nil] subscription tag (for :animation_frame)([Symbol, nil]() ⇒ Object (readonly)
System events for theme changes, animation frames, and other runtime signals. Triggered by OS-level changes or renderer lifecycle events. Subscribe via Subscription.on_theme_change or on_animation_frame.
277 278 279 280 281 |
# File 'lib/plushie/event.rb', line 277 System = Data.define(:type, :tag, :data) do def initialize(type:, tag: nil, data: nil) super end end |
#type ⇒ Object (readonly)
Returns the value of attribute type
277 278 279 |
# File 'lib/plushie/event.rb', line 277 def type @type end |
#type [Symbol] :theme_changed, :animation_frame([Symbol], : animation_frame) ⇒ Object (readonly)
System events for theme changes, animation frames, and other runtime signals. Triggered by OS-level changes or renderer lifecycle events. Subscribe via Subscription.on_theme_change or on_animation_frame.
277 278 279 280 281 |
# File 'lib/plushie/event.rb', line 277 System = Data.define(:type, :tag, :data) do def initialize(type:, tag: nil, data: nil) super end end |